@@ -18,11 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkcolour3d.c,v 1.53 2013/06/16 02:16:22 mdpetch Exp $
+ * $Id: gtkcolour3d.c,v 1.55 2013/12/01 17:06:34 mdpetch Exp $
  */
 
 #include "config.h"
 #include "inc3d.h"
+#include "gtklocdefs.h"
 
 #include "gtkprefs.h"
 
@@ -85,15 +86,15 @@ SetupLight(void)
     float lp[4] = { PREVIEW_WIDTH / 2, PREVIEW_HEIGHT / 2, 50, 1 };
     glLightfv(GL_LIGHT0, GL_POSITION, lp);
 
-    al[0] = al[1] = al[2] = previewLightLevels[0] / 100.0f;
+    al[0] = al[1] = al[2] = (float) previewLightLevels[0] / 100.0f;
     al[3] = 1;
     glLightfv(GL_LIGHT0, GL_AMBIENT, al);
 
-    dl[0] = dl[1] = dl[2] = previewLightLevels[1] / 100.0f;
+    dl[0] = dl[1] = dl[2] = (float) previewLightLevels[1] / 100.0f;
     dl[3] = 1;
     glLightfv(GL_LIGHT0, GL_DIFFUSE, dl);
 
-    sl[0] = sl[1] = sl[2] = previewLightLevels[2] / 100.0f;
+    sl[0] = sl[1] = sl[2] = (float) previewLightLevels[2] / 100.0f;
     sl[3] = 1;
     glLightfv(GL_LIGHT0, GL_SPECULAR, sl);
 }
@@ -124,7 +125,7 @@ Draw(Material * pMat)
             glScalef(1.f, HINGE_SEGMENTS, 1.f);
         } else {
             glRotatef(-90.f, 0.f, 0.f, 1.f);
-            glScalef(TEXTURE_SCALE / texture.width, TEXTURE_SCALE / texture.height, 1.f);
+            glScalef(TEXTURE_SCALE / (float) texture.width, TEXTURE_SCALE / (float) texture.height, 1.f);
         }
         glMatrixMode(GL_MODELVIEW);
     } else {
@@ -202,9 +203,9 @@ SetupColourPreview(void)
 }
 
 static void
-TextureChange(GtkComboBox * combo, gpointer UNUSED(data))
+TextureChange(GtkComboBoxText * combo, gpointer UNUSED(data))
 {
-    char *current = gtk_combo_box_get_active_text(combo);
+    char *current = gtk_combo_box_text_get_active_text(combo);
 
     if (!bUpdate)
         return;
@@ -340,7 +341,7 @@ AddWidgets(GtkWidget * window)
 
     pTexturelabel = gtk_label_new(_("Texture:"));
     gtk_table_attach_defaults(GTK_TABLE(table), pTexturelabel, 2, 3, 2, 3);
-    textureComboBox = gtk_combo_box_new_text();
+    textureComboBox = GTK_WIDGET(gtk_combo_box_text_new());
     texture_set_active();
     gtk_widget_set_sensitive(textureComboBox, FALSE);
     g_signal_connect(textureComboBox, "changed", G_CALLBACK(TextureChange), NULL);
@@ -364,7 +365,7 @@ DialogClose(GtkDialog * UNUSED(dialog), gint response, void *UNUSED(data))
         *curDetails->pBoardMat = col3d;
 
         if (useTexture) {
-            texStr = gtk_combo_box_get_active_text(GTK_COMBO_BOX(textureComboBox));
+            texStr = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(textureComboBox));
 
             if (!strcmp(texStr, NO_TEXTURE_STRING))
                 col3d.textureInfo = 0;
@@ -385,7 +386,7 @@ DialogClose(GtkDialog * UNUSED(dialog), gint response, void *UNUSED(data))
 static void
 append_to_combo_box( /*lint -e{818} */ gpointer data, gpointer combo)
 {
-    gtk_combo_box_append_text(combo, data);
+    gtk_combo_box_text_append_text(combo, data);
 }
 
 static void
