@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkpanels.c,v 1.74 2013/06/18 21:21:13 plm Exp $
+ * $Id: gtkpanels.c,v 1.78 2014/07/20 21:16:30 plm Exp $
  */
 
 #include "config.h"
@@ -87,7 +87,7 @@ typedef struct _windowobject {
 } windowobject;
 
 /* Set up window and panel details */
-windowobject woPanel[NUM_WINDOWS] = {
+static windowobject woPanel[NUM_WINDOWS] = {
     /* main window */
     {
      "main",
@@ -292,7 +292,7 @@ CreateMessageWindow(void)
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(psw), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
     gtk_widget_set_size_request(psw, -1, 150);
     gtk_container_add(GTK_CONTAINER(psw), pwMessageText);
-    CreatePanel(WINDOW_MESSAGE, psw, _("Messages - GNU Backgammon"), "messages");
+    CreatePanel(WINDOW_MESSAGE, psw, _("GNU Backgammon - Messages"), "messages");
 }
 
 static GtkWidget *pwTheoryView = NULL;
@@ -318,7 +318,7 @@ UpdateTheoryData(BoardData * bd, int UpdateType, const TanBoard points)
             if (diff == 0)
                 pc = g_strdup_printf(_("equal"));
             else
-                pc = g_strdup_printf("%d %s", abs(anPip[0] - anPip[1]), (diff > 0) ? _("ahead") : _("behind"));
+                pc = g_strdup_printf("%d %s", abs(diff), (diff > 0) ? _("ahead") : _("behind"));
 
             gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(store), &iter, NULL, 0);
             gtk_list_store_set(store, &iter, 1, pc, -1);
@@ -403,7 +403,7 @@ CreateTheoryWindow(void)
     gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(pwTheoryView), -1, NULL, renderer, "text", 1, NULL);
     gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(pwTheoryView), FALSE);
 
-    CreatePanel(WINDOW_THEORY, pwTheoryView, _("Theory - GNU Backgammon"), "theory");
+    CreatePanel(WINDOW_THEORY, pwTheoryView, _("GNU Backgammon - Theory"), "theory");
     return woPanel[WINDOW_THEORY].pwWin;
 }
 
@@ -625,7 +625,7 @@ CreateCommandWindow(void)
     GtkWidget *pwvbox = gtk_vbox_new(FALSE, 0);
     GtkWidget *pwShowHelp;
 
-    CreatePanel(WINDOW_COMMAND, pwvbox, _("Command - GNU Backgammon"), "command");
+    CreatePanel(WINDOW_COMMAND, pwvbox, _("GNU Backgammon - Command"), "command");
 
     cedPanel.cmdString = NULL;
     cedPanel.pwHelpText = pwMessageText;
@@ -665,7 +665,7 @@ CreateAnalysisWindow(void)
 
         woPanel[WINDOW_ANALYSIS].pwWin = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
-        gtk_window_set_title(GTK_WINDOW(woPanel[WINDOW_ANALYSIS].pwWin), _("Annotation - GNU Backgammon"));
+        gtk_window_set_title(GTK_WINDOW(woPanel[WINDOW_ANALYSIS].pwWin), _("GNU Backgammon - Annotation"));
         gtk_window_set_role(GTK_WINDOW(woPanel[WINDOW_ANALYSIS].pwWin), "annotation");
         gtk_window_set_type_hint(GTK_WINDOW(woPanel[WINDOW_ANALYSIS].pwWin), GDK_WINDOW_TYPE_HINT_UTILITY);
 
@@ -796,7 +796,7 @@ CreateGameWindow(void)
     if (!woPanel[WINDOW_GAME].docked) {
         woPanel[WINDOW_GAME].pwWin = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
-        gtk_window_set_title(GTK_WINDOW(woPanel[WINDOW_GAME].pwWin), _("Game record - GNU Backgammon"));
+        gtk_window_set_title(GTK_WINDOW(woPanel[WINDOW_GAME].pwWin), _("GNU Backgammon - Game record"));
         gtk_window_set_role(GTK_WINDOW(woPanel[WINDOW_GAME].pwWin), "game record");
         gtk_window_set_type_hint(GTK_WINDOW(woPanel[WINDOW_GAME].pwWin), GDK_WINDOW_TYPE_HINT_UTILITY);
 
@@ -1278,7 +1278,7 @@ HideAllPanels(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
 
 #if (USE_GTKUIMANAGER)
 void
-ToggleDockPanels(GtkToggleAction * action, gpointer user_data)
+ToggleDockPanels(GtkToggleAction * action, gpointer UNUSED(user_data))
 {
     int newValue = gtk_toggle_action_get_active(action);
     if (fDockPanels != newValue) {
@@ -1451,7 +1451,7 @@ CommandSetAnalysisWindows(char *sz)
               _("Show window with analysis"), _("Do not show window with analysis."));
 }
 
-gnubgwindow pwoSetPanel;
+static gnubgwindow pwoSetPanel;
 
 extern void
 CommandSetGeometryAnalysis(char *sz)
