@@ -16,13 +16,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtktheory.h,v 1.2 2007/07/02 12:43:39 ace Exp $
+ * $Id: gtktheory.h,v 1.4 2013/06/16 02:16:17 mdpetch Exp $
  */
 
-#ifndef _GTKTHEORY_H_
-#define _GTKTHEORY_H_
+#ifndef GTKTHEORY_H
+#define GTKTHEORY_H
 
 extern void
-GTKShowTheory ( const int fActivePage );
+ GTKShowTheory(const int fActivePage);
 
 #endif
